# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: router.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from lndmanage.grpc_compiled import lightning_pb2 as lightning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='router.proto',
  package='routerrpc',
  syntax='proto3',
  serialized_options=b'Z/github.com/lightningnetwork/lnd/lnrpc/routerrpc',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0crouter.proto\x12\trouterrpc\x1a\x0flightning.proto\"\xa4\x05\n\x12SendPaymentRequest\x12\x0c\n\x04\x64\x65st\x18\x01 \x01(\x0c\x12\x0b\n\x03\x61mt\x18\x02 \x01(\x03\x12\x10\n\x08\x61mt_msat\x18\x0c \x01(\x03\x12\x14\n\x0cpayment_hash\x18\x03 \x01(\x0c\x12\x18\n\x10\x66inal_cltv_delta\x18\x04 \x01(\x05\x12\x14\n\x0cpayment_addr\x18\x14 \x01(\x0c\x12\x17\n\x0fpayment_request\x18\x05 \x01(\t\x12\x17\n\x0ftimeout_seconds\x18\x06 \x01(\x05\x12\x15\n\rfee_limit_sat\x18\x07 \x01(\x03\x12\x16\n\x0e\x66\x65\x65_limit_msat\x18\r \x01(\x03\x12\x1e\n\x10outgoing_chan_id\x18\x08 \x01(\x04\x42\x04\x18\x01\x30\x01\x12\x19\n\x11outgoing_chan_ids\x18\x13 \x03(\x04\x12\x17\n\x0flast_hop_pubkey\x18\x0e \x01(\x0c\x12\x12\n\ncltv_limit\x18\t \x01(\x05\x12%\n\x0broute_hints\x18\n \x03(\x0b\x32\x10.lnrpc.RouteHint\x12Q\n\x13\x64\x65st_custom_records\x18\x0b \x03(\x0b\x32\x34.routerrpc.SendPaymentRequest.DestCustomRecordsEntry\x12\x1a\n\x12\x61llow_self_payment\x18\x0f \x01(\x08\x12(\n\rdest_features\x18\x10 \x03(\x0e\x32\x11.lnrpc.FeatureBit\x12\x11\n\tmax_parts\x18\x11 \x01(\r\x12\x1b\n\x13no_inflight_updates\x18\x12 \x01(\x08\x12\x1b\n\x13max_shard_size_msat\x18\x15 \x01(\x04\x12\x0b\n\x03\x61mp\x18\x16 \x01(\x08\x1a\x38\n\x16\x44\x65stCustomRecordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"H\n\x13TrackPaymentRequest\x12\x14\n\x0cpayment_hash\x18\x01 \x01(\x0c\x12\x1b\n\x13no_inflight_updates\x18\x02 \x01(\x08\"0\n\x0fRouteFeeRequest\x12\x0c\n\x04\x64\x65st\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61mt_sat\x18\x02 \x01(\x03\"E\n\x10RouteFeeResponse\x12\x18\n\x10routing_fee_msat\x18\x01 \x01(\x03\x12\x17\n\x0ftime_lock_delay\x18\x02 \x01(\x03\"G\n\x12SendToRouteRequest\x12\x14\n\x0cpayment_hash\x18\x01 \x01(\x0c\x12\x1b\n\x05route\x18\x02 \x01(\x0b\x32\x0c.lnrpc.Route\"H\n\x13SendToRouteResponse\x12\x10\n\x08preimage\x18\x01 \x01(\x0c\x12\x1f\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x0e.lnrpc.Failure\"\x1c\n\x1aResetMissionControlRequest\"\x1d\n\x1bResetMissionControlResponse\"\x1c\n\x1aQueryMissionControlRequest\"J\n\x1bQueryMissionControlResponse\x12%\n\x05pairs\x18\x02 \x03(\x0b\x32\x16.routerrpc.PairHistoryJ\x04\x08\x01\x10\x02\"T\n\x1cXImportMissionControlRequest\x12%\n\x05pairs\x18\x01 \x03(\x0b\x32\x16.routerrpc.PairHistory\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"\x1f\n\x1dXImportMissionControlResponse\"o\n\x0bPairHistory\x12\x11\n\tnode_from\x18\x01 \x01(\x0c\x12\x0f\n\x07node_to\x18\x02 \x01(\x0c\x12$\n\x07history\x18\x07 \x01(\x0b\x32\x13.routerrpc.PairDataJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\x99\x01\n\x08PairData\x12\x11\n\tfail_time\x18\x01 \x01(\x03\x12\x14\n\x0c\x66\x61il_amt_sat\x18\x02 \x01(\x03\x12\x15\n\rfail_amt_msat\x18\x04 \x01(\x03\x12\x14\n\x0csuccess_time\x18\x05 \x01(\x03\x12\x17\n\x0fsuccess_amt_sat\x18\x06 \x01(\x03\x12\x18\n\x10success_amt_msat\x18\x07 \x01(\x03J\x04\x08\x03\x10\x04\" \n\x1eGetMissionControlConfigRequest\"R\n\x1fGetMissionControlConfigResponse\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.routerrpc.MissionControlConfig\"Q\n\x1eSetMissionControlConfigRequest\x12/\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x1f.routerrpc.MissionControlConfig\"!\n\x1fSetMissionControlConfigResponse\"\xa3\x01\n\x14MissionControlConfig\x12\x19\n\x11half_life_seconds\x18\x01 \x01(\x04\x12\x17\n\x0fhop_probability\x18\x02 \x01(\x02\x12\x0e\n\x06weight\x18\x03 \x01(\x02\x12\x1f\n\x17maximum_payment_results\x18\x04 \x01(\r\x12&\n\x1eminimum_failure_relax_interval\x18\x05 \x01(\x04\"O\n\x17QueryProbabilityRequest\x12\x11\n\tfrom_node\x18\x01 \x01(\x0c\x12\x0f\n\x07to_node\x18\x02 \x01(\x0c\x12\x10\n\x08\x61mt_msat\x18\x03 \x01(\x03\"U\n\x18QueryProbabilityResponse\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12$\n\x07history\x18\x02 \x01(\x0b\x32\x13.routerrpc.PairData\"\x88\x01\n\x11\x42uildRouteRequest\x12\x10\n\x08\x61mt_msat\x18\x01 \x01(\x03\x12\x18\n\x10\x66inal_cltv_delta\x18\x02 \x01(\x05\x12\x1c\n\x10outgoing_chan_id\x18\x03 \x01(\x04\x42\x02\x30\x01\x12\x13\n\x0bhop_pubkeys\x18\x04 \x03(\x0c\x12\x14\n\x0cpayment_addr\x18\x05 \x01(\x0c\"1\n\x12\x42uildRouteResponse\x12\x1b\n\x05route\x18\x01 \x01(\x0b\x32\x0c.lnrpc.Route\"\x1c\n\x1aSubscribeHtlcEventsRequest\"\xdc\x03\n\tHtlcEvent\x12\x1b\n\x13incoming_channel_id\x18\x01 \x01(\x04\x12\x1b\n\x13outgoing_channel_id\x18\x02 \x01(\x04\x12\x18\n\x10incoming_htlc_id\x18\x03 \x01(\x04\x12\x18\n\x10outgoing_htlc_id\x18\x04 \x01(\x04\x12\x14\n\x0ctimestamp_ns\x18\x05 \x01(\x04\x12\x32\n\nevent_type\x18\x06 \x01(\x0e\x32\x1e.routerrpc.HtlcEvent.EventType\x12\x30\n\rforward_event\x18\x07 \x01(\x0b\x32\x17.routerrpc.ForwardEventH\x00\x12\x39\n\x12\x66orward_fail_event\x18\x08 \x01(\x0b\x32\x1b.routerrpc.ForwardFailEventH\x00\x12.\n\x0csettle_event\x18\t \x01(\x0b\x32\x16.routerrpc.SettleEventH\x00\x12\x33\n\x0flink_fail_event\x18\n \x01(\x0b\x32\x18.routerrpc.LinkFailEventH\x00\"<\n\tEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04SEND\x10\x01\x12\x0b\n\x07RECEIVE\x10\x02\x12\x0b\n\x07\x46ORWARD\x10\x03\x42\x07\n\x05\x65vent\"v\n\x08HtlcInfo\x12\x19\n\x11incoming_timelock\x18\x01 \x01(\r\x12\x19\n\x11outgoing_timelock\x18\x02 \x01(\r\x12\x19\n\x11incoming_amt_msat\x18\x03 \x01(\x04\x12\x19\n\x11outgoing_amt_msat\x18\x04 \x01(\x04\"1\n\x0c\x46orwardEvent\x12!\n\x04info\x18\x01 \x01(\x0b\x32\x13.routerrpc.HtlcInfo\"\x12\n\x10\x46orwardFailEvent\"\x1f\n\x0bSettleEvent\x12\x10\n\x08preimage\x18\x01 \x01(\x0c\"\xae\x01\n\rLinkFailEvent\x12!\n\x04info\x18\x01 \x01(\x0b\x32\x13.routerrpc.HtlcInfo\x12\x30\n\x0cwire_failure\x18\x02 \x01(\x0e\x32\x1a.lnrpc.Failure.FailureCode\x12\x30\n\x0e\x66\x61ilure_detail\x18\x03 \x01(\x0e\x32\x18.routerrpc.FailureDetail\x12\x16\n\x0e\x66\x61ilure_string\x18\x04 \x01(\t\"r\n\rPaymentStatus\x12&\n\x05state\x18\x01 \x01(\x0e\x32\x17.routerrpc.PaymentState\x12\x10\n\x08preimage\x18\x02 \x01(\x0c\x12!\n\x05htlcs\x18\x04 \x03(\x0b\x32\x12.lnrpc.HTLCAttemptJ\x04\x08\x03\x10\x04\".\n\nCircuitKey\x12\x0f\n\x07\x63han_id\x18\x01 \x01(\x04\x12\x0f\n\x07htlc_id\x18\x02 \x01(\x04\"\x97\x03\n\x1b\x46orwardHtlcInterceptRequest\x12\x33\n\x14incoming_circuit_key\x18\x01 \x01(\x0b\x32\x15.routerrpc.CircuitKey\x12\x1c\n\x14incoming_amount_msat\x18\x05 \x01(\x04\x12\x17\n\x0fincoming_expiry\x18\x06 \x01(\r\x12\x14\n\x0cpayment_hash\x18\x02 \x01(\x0c\x12\"\n\x1aoutgoing_requested_chan_id\x18\x07 \x01(\x04\x12\x1c\n\x14outgoing_amount_msat\x18\x03 \x01(\x04\x12\x17\n\x0foutgoing_expiry\x18\x04 \x01(\r\x12Q\n\x0e\x63ustom_records\x18\x08 \x03(\x0b\x32\x39.routerrpc.ForwardHtlcInterceptRequest.CustomRecordsEntry\x12\x12\n\nonion_blob\x18\t \x01(\x0c\x1a\x34\n\x12\x43ustomRecordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x04\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x9a\x01\n\x1c\x46orwardHtlcInterceptResponse\x12\x33\n\x14incoming_circuit_key\x18\x01 \x01(\x0b\x32\x15.routerrpc.CircuitKey\x12\x33\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32#.routerrpc.ResolveHoldForwardAction\x12\x10\n\x08preimage\x18\x03 \x01(\x0c\"o\n\x17UpdateChanStatusRequest\x12\'\n\nchan_point\x18\x01 \x01(\x0b\x32\x13.lnrpc.ChannelPoint\x12+\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x1b.routerrpc.ChanStatusAction\"\x1a\n\x18UpdateChanStatusResponse*\x81\x04\n\rFailureDetail\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tNO_DETAIL\x10\x01\x12\x10\n\x0cONION_DECODE\x10\x02\x12\x15\n\x11LINK_NOT_ELIGIBLE\x10\x03\x12\x14\n\x10ON_CHAIN_TIMEOUT\x10\x04\x12\x14\n\x10HTLC_EXCEEDS_MAX\x10\x05\x12\x18\n\x14INSUFFICIENT_BALANCE\x10\x06\x12\x16\n\x12INCOMPLETE_FORWARD\x10\x07\x12\x13\n\x0fHTLC_ADD_FAILED\x10\x08\x12\x15\n\x11\x46ORWARDS_DISABLED\x10\t\x12\x14\n\x10INVOICE_CANCELED\x10\n\x12\x15\n\x11INVOICE_UNDERPAID\x10\x0b\x12\x1b\n\x17INVOICE_EXPIRY_TOO_SOON\x10\x0c\x12\x14\n\x10INVOICE_NOT_OPEN\x10\r\x12\x17\n\x13MPP_INVOICE_TIMEOUT\x10\x0e\x12\x14\n\x10\x41\x44\x44RESS_MISMATCH\x10\x0f\x12\x16\n\x12SET_TOTAL_MISMATCH\x10\x10\x12\x15\n\x11SET_TOTAL_TOO_LOW\x10\x11\x12\x10\n\x0cSET_OVERPAID\x10\x12\x12\x13\n\x0fUNKNOWN_INVOICE\x10\x13\x12\x13\n\x0fINVALID_KEYSEND\x10\x14\x12\x13\n\x0fMPP_IN_PROGRESS\x10\x15\x12\x12\n\x0e\x43IRCULAR_ROUTE\x10\x16*\xae\x01\n\x0cPaymentState\x12\r\n\tIN_FLIGHT\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\x12\n\x0e\x46\x41ILED_TIMEOUT\x10\x02\x12\x13\n\x0f\x46\x41ILED_NO_ROUTE\x10\x03\x12\x10\n\x0c\x46\x41ILED_ERROR\x10\x04\x12$\n FAILED_INCORRECT_PAYMENT_DETAILS\x10\x05\x12\x1f\n\x1b\x46\x41ILED_INSUFFICIENT_BALANCE\x10\x06*<\n\x18ResolveHoldForwardAction\x12\n\n\x06SETTLE\x10\x00\x12\x08\n\x04\x46\x41IL\x10\x01\x12\n\n\x06RESUME\x10\x02*5\n\x10\x43hanStatusAction\x12\n\n\x06\x45NABLE\x10\x00\x12\x0b\n\x07\x44ISABLE\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\x32\xf1\x0b\n\x06Router\x12@\n\rSendPaymentV2\x12\x1d.routerrpc.SendPaymentRequest\x1a\x0e.lnrpc.Payment0\x01\x12\x42\n\x0eTrackPaymentV2\x12\x1e.routerrpc.TrackPaymentRequest\x1a\x0e.lnrpc.Payment0\x01\x12K\n\x10\x45stimateRouteFee\x12\x1a.routerrpc.RouteFeeRequest\x1a\x1b.routerrpc.RouteFeeResponse\x12Q\n\x0bSendToRoute\x12\x1d.routerrpc.SendToRouteRequest\x1a\x1e.routerrpc.SendToRouteResponse\"\x03\x88\x02\x01\x12\x42\n\rSendToRouteV2\x12\x1d.routerrpc.SendToRouteRequest\x1a\x12.lnrpc.HTLCAttempt\x12\x64\n\x13ResetMissionControl\x12%.routerrpc.ResetMissionControlRequest\x1a&.routerrpc.ResetMissionControlResponse\x12\x64\n\x13QueryMissionControl\x12%.routerrpc.QueryMissionControlRequest\x1a&.routerrpc.QueryMissionControlResponse\x12j\n\x15XImportMissionControl\x12\'.routerrpc.XImportMissionControlRequest\x1a(.routerrpc.XImportMissionControlResponse\x12p\n\x17GetMissionControlConfig\x12).routerrpc.GetMissionControlConfigRequest\x1a*.routerrpc.GetMissionControlConfigResponse\x12p\n\x17SetMissionControlConfig\x12).routerrpc.SetMissionControlConfigRequest\x1a*.routerrpc.SetMissionControlConfigResponse\x12[\n\x10QueryProbability\x12\".routerrpc.QueryProbabilityRequest\x1a#.routerrpc.QueryProbabilityResponse\x12I\n\nBuildRoute\x12\x1c.routerrpc.BuildRouteRequest\x1a\x1d.routerrpc.BuildRouteResponse\x12T\n\x13SubscribeHtlcEvents\x12%.routerrpc.SubscribeHtlcEventsRequest\x1a\x14.routerrpc.HtlcEvent0\x01\x12M\n\x0bSendPayment\x12\x1d.routerrpc.SendPaymentRequest\x1a\x18.routerrpc.PaymentStatus\"\x03\x88\x02\x01\x30\x01\x12O\n\x0cTrackPayment\x12\x1e.routerrpc.TrackPaymentRequest\x1a\x18.routerrpc.PaymentStatus\"\x03\x88\x02\x01\x30\x01\x12\x66\n\x0fHtlcInterceptor\x12\'.routerrpc.ForwardHtlcInterceptResponse\x1a&.routerrpc.ForwardHtlcInterceptRequest(\x01\x30\x01\x12[\n\x10UpdateChanStatus\x12\".routerrpc.UpdateChanStatusRequest\x1a#.routerrpc.UpdateChanStatusResponseB1Z/github.com/lightningnetwork/lnd/lnrpc/routerrpcb\x06proto3'
  ,
  dependencies=[lightning__pb2.DESCRIPTOR,])

_FAILUREDETAIL = _descriptor.EnumDescriptor(
  name='FailureDetail',
  full_name='routerrpc.FailureDetail',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_DETAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONION_DECODE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINK_NOT_ELIGIBLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ON_CHAIN_TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTLC_EXCEEDS_MAX', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INSUFFICIENT_BALANCE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INCOMPLETE_FORWARD', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTLC_ADD_FAILED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORWARDS_DISABLED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVOICE_CANCELED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVOICE_UNDERPAID', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVOICE_EXPIRY_TOO_SOON', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVOICE_NOT_OPEN', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MPP_INVOICE_TIMEOUT', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS_MISMATCH', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SET_TOTAL_MISMATCH', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SET_TOTAL_TOO_LOW', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SET_OVERPAID', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_INVOICE', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_KEYSEND', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MPP_IN_PROGRESS', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CIRCULAR_ROUTE', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4163,
  serialized_end=4676,
)
_sym_db.RegisterEnumDescriptor(_FAILUREDETAIL)

FailureDetail = enum_type_wrapper.EnumTypeWrapper(_FAILUREDETAIL)
_PAYMENTSTATE = _descriptor.EnumDescriptor(
  name='PaymentState',
  full_name='routerrpc.PaymentState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IN_FLIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_NO_ROUTE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_INCORRECT_PAYMENT_DETAILS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED_INSUFFICIENT_BALANCE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4679,
  serialized_end=4853,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTSTATE)

PaymentState = enum_type_wrapper.EnumTypeWrapper(_PAYMENTSTATE)
_RESOLVEHOLDFORWARDACTION = _descriptor.EnumDescriptor(
  name='ResolveHoldForwardAction',
  full_name='routerrpc.ResolveHoldForwardAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SETTLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESUME', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4855,
  serialized_end=4915,
)
_sym_db.RegisterEnumDescriptor(_RESOLVEHOLDFORWARDACTION)

ResolveHoldForwardAction = enum_type_wrapper.EnumTypeWrapper(_RESOLVEHOLDFORWARDACTION)
_CHANSTATUSACTION = _descriptor.EnumDescriptor(
  name='ChanStatusAction',
  full_name='routerrpc.ChanStatusAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4917,
  serialized_end=4970,
)
_sym_db.RegisterEnumDescriptor(_CHANSTATUSACTION)

ChanStatusAction = enum_type_wrapper.EnumTypeWrapper(_CHANSTATUSACTION)
UNKNOWN = 0
NO_DETAIL = 1
ONION_DECODE = 2
LINK_NOT_ELIGIBLE = 3
ON_CHAIN_TIMEOUT = 4
HTLC_EXCEEDS_MAX = 5
INSUFFICIENT_BALANCE = 6
INCOMPLETE_FORWARD = 7
HTLC_ADD_FAILED = 8
FORWARDS_DISABLED = 9
INVOICE_CANCELED = 10
INVOICE_UNDERPAID = 11
INVOICE_EXPIRY_TOO_SOON = 12
INVOICE_NOT_OPEN = 13
MPP_INVOICE_TIMEOUT = 14
ADDRESS_MISMATCH = 15
SET_TOTAL_MISMATCH = 16
SET_TOTAL_TOO_LOW = 17
SET_OVERPAID = 18
UNKNOWN_INVOICE = 19
INVALID_KEYSEND = 20
MPP_IN_PROGRESS = 21
CIRCULAR_ROUTE = 22
IN_FLIGHT = 0
SUCCEEDED = 1
FAILED_TIMEOUT = 2
FAILED_NO_ROUTE = 3
FAILED_ERROR = 4
FAILED_INCORRECT_PAYMENT_DETAILS = 5
FAILED_INSUFFICIENT_BALANCE = 6
SETTLE = 0
FAIL = 1
RESUME = 2
ENABLE = 0
DISABLE = 1
AUTO = 2


_HTLCEVENT_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='routerrpc.HtlcEvent.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECEIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORWARD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2818,
  serialized_end=2878,
)
_sym_db.RegisterEnumDescriptor(_HTLCEVENT_EVENTTYPE)


_SENDPAYMENTREQUEST_DESTCUSTOMRECORDSENTRY = _descriptor.Descriptor(
  name='DestCustomRecordsEntry',
  full_name='routerrpc.SendPaymentRequest.DestCustomRecordsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='routerrpc.SendPaymentRequest.DestCustomRecordsEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='routerrpc.SendPaymentRequest.DestCustomRecordsEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=665,
  serialized_end=721,
)

_SENDPAYMENTREQUEST = _descriptor.Descriptor(
  name='SendPaymentRequest',
  full_name='routerrpc.SendPaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dest', full_name='routerrpc.SendPaymentRequest.dest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amt', full_name='routerrpc.SendPaymentRequest.amt', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amt_msat', full_name='routerrpc.SendPaymentRequest.amt_msat', index=2,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.SendPaymentRequest.payment_hash', index=3,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final_cltv_delta', full_name='routerrpc.SendPaymentRequest.final_cltv_delta', index=4,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_addr', full_name='routerrpc.SendPaymentRequest.payment_addr', index=5,
      number=20, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_request', full_name='routerrpc.SendPaymentRequest.payment_request', index=6,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_seconds', full_name='routerrpc.SendPaymentRequest.timeout_seconds', index=7,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit_sat', full_name='routerrpc.SendPaymentRequest.fee_limit_sat', index=8,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee_limit_msat', full_name='routerrpc.SendPaymentRequest.fee_limit_msat', index=9,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_chan_id', full_name='routerrpc.SendPaymentRequest.outgoing_chan_id', index=10,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\0010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_chan_ids', full_name='routerrpc.SendPaymentRequest.outgoing_chan_ids', index=11,
      number=19, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_hop_pubkey', full_name='routerrpc.SendPaymentRequest.last_hop_pubkey', index=12,
      number=14, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cltv_limit', full_name='routerrpc.SendPaymentRequest.cltv_limit', index=13,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_hints', full_name='routerrpc.SendPaymentRequest.route_hints', index=14,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dest_custom_records', full_name='routerrpc.SendPaymentRequest.dest_custom_records', index=15,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_self_payment', full_name='routerrpc.SendPaymentRequest.allow_self_payment', index=16,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dest_features', full_name='routerrpc.SendPaymentRequest.dest_features', index=17,
      number=16, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_parts', full_name='routerrpc.SendPaymentRequest.max_parts', index=18,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_inflight_updates', full_name='routerrpc.SendPaymentRequest.no_inflight_updates', index=19,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_shard_size_msat', full_name='routerrpc.SendPaymentRequest.max_shard_size_msat', index=20,
      number=21, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amp', full_name='routerrpc.SendPaymentRequest.amp', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SENDPAYMENTREQUEST_DESTCUSTOMRECORDSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=721,
)


_TRACKPAYMENTREQUEST = _descriptor.Descriptor(
  name='TrackPaymentRequest',
  full_name='routerrpc.TrackPaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.TrackPaymentRequest.payment_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_inflight_updates', full_name='routerrpc.TrackPaymentRequest.no_inflight_updates', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=723,
  serialized_end=795,
)


_ROUTEFEEREQUEST = _descriptor.Descriptor(
  name='RouteFeeRequest',
  full_name='routerrpc.RouteFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dest', full_name='routerrpc.RouteFeeRequest.dest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amt_sat', full_name='routerrpc.RouteFeeRequest.amt_sat', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=845,
)


_ROUTEFEERESPONSE = _descriptor.Descriptor(
  name='RouteFeeResponse',
  full_name='routerrpc.RouteFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_fee_msat', full_name='routerrpc.RouteFeeResponse.routing_fee_msat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_lock_delay', full_name='routerrpc.RouteFeeResponse.time_lock_delay', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=916,
)


_SENDTOROUTEREQUEST = _descriptor.Descriptor(
  name='SendToRouteRequest',
  full_name='routerrpc.SendToRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.SendToRouteRequest.payment_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route', full_name='routerrpc.SendToRouteRequest.route', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=918,
  serialized_end=989,
)


_SENDTOROUTERESPONSE = _descriptor.Descriptor(
  name='SendToRouteResponse',
  full_name='routerrpc.SendToRouteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preimage', full_name='routerrpc.SendToRouteResponse.preimage', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure', full_name='routerrpc.SendToRouteResponse.failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=991,
  serialized_end=1063,
)


_RESETMISSIONCONTROLREQUEST = _descriptor.Descriptor(
  name='ResetMissionControlRequest',
  full_name='routerrpc.ResetMissionControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1065,
  serialized_end=1093,
)


_RESETMISSIONCONTROLRESPONSE = _descriptor.Descriptor(
  name='ResetMissionControlResponse',
  full_name='routerrpc.ResetMissionControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1095,
  serialized_end=1124,
)


_QUERYMISSIONCONTROLREQUEST = _descriptor.Descriptor(
  name='QueryMissionControlRequest',
  full_name='routerrpc.QueryMissionControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1126,
  serialized_end=1154,
)


_QUERYMISSIONCONTROLRESPONSE = _descriptor.Descriptor(
  name='QueryMissionControlResponse',
  full_name='routerrpc.QueryMissionControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pairs', full_name='routerrpc.QueryMissionControlResponse.pairs', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1156,
  serialized_end=1230,
)


_XIMPORTMISSIONCONTROLREQUEST = _descriptor.Descriptor(
  name='XImportMissionControlRequest',
  full_name='routerrpc.XImportMissionControlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pairs', full_name='routerrpc.XImportMissionControlRequest.pairs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='routerrpc.XImportMissionControlRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1232,
  serialized_end=1316,
)


_XIMPORTMISSIONCONTROLRESPONSE = _descriptor.Descriptor(
  name='XImportMissionControlResponse',
  full_name='routerrpc.XImportMissionControlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1318,
  serialized_end=1349,
)


_PAIRHISTORY = _descriptor.Descriptor(
  name='PairHistory',
  full_name='routerrpc.PairHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_from', full_name='routerrpc.PairHistory.node_from', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_to', full_name='routerrpc.PairHistory.node_to', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='history', full_name='routerrpc.PairHistory.history', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1351,
  serialized_end=1462,
)


_PAIRDATA = _descriptor.Descriptor(
  name='PairData',
  full_name='routerrpc.PairData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fail_time', full_name='routerrpc.PairData.fail_time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_amt_sat', full_name='routerrpc.PairData.fail_amt_sat', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fail_amt_msat', full_name='routerrpc.PairData.fail_amt_msat', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_time', full_name='routerrpc.PairData.success_time', index=3,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_amt_sat', full_name='routerrpc.PairData.success_amt_sat', index=4,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success_amt_msat', full_name='routerrpc.PairData.success_amt_msat', index=5,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1465,
  serialized_end=1618,
)


_GETMISSIONCONTROLCONFIGREQUEST = _descriptor.Descriptor(
  name='GetMissionControlConfigRequest',
  full_name='routerrpc.GetMissionControlConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1620,
  serialized_end=1652,
)


_GETMISSIONCONTROLCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetMissionControlConfigResponse',
  full_name='routerrpc.GetMissionControlConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='routerrpc.GetMissionControlConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1736,
)


_SETMISSIONCONTROLCONFIGREQUEST = _descriptor.Descriptor(
  name='SetMissionControlConfigRequest',
  full_name='routerrpc.SetMissionControlConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='routerrpc.SetMissionControlConfigRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1738,
  serialized_end=1819,
)


_SETMISSIONCONTROLCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetMissionControlConfigResponse',
  full_name='routerrpc.SetMissionControlConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1821,
  serialized_end=1854,
)


_MISSIONCONTROLCONFIG = _descriptor.Descriptor(
  name='MissionControlConfig',
  full_name='routerrpc.MissionControlConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='half_life_seconds', full_name='routerrpc.MissionControlConfig.half_life_seconds', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hop_probability', full_name='routerrpc.MissionControlConfig.hop_probability', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='routerrpc.MissionControlConfig.weight', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_payment_results', full_name='routerrpc.MissionControlConfig.maximum_payment_results', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_failure_relax_interval', full_name='routerrpc.MissionControlConfig.minimum_failure_relax_interval', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1857,
  serialized_end=2020,
)


_QUERYPROBABILITYREQUEST = _descriptor.Descriptor(
  name='QueryProbabilityRequest',
  full_name='routerrpc.QueryProbabilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_node', full_name='routerrpc.QueryProbabilityRequest.from_node', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_node', full_name='routerrpc.QueryProbabilityRequest.to_node', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amt_msat', full_name='routerrpc.QueryProbabilityRequest.amt_msat', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2022,
  serialized_end=2101,
)


_QUERYPROBABILITYRESPONSE = _descriptor.Descriptor(
  name='QueryProbabilityResponse',
  full_name='routerrpc.QueryProbabilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='routerrpc.QueryProbabilityResponse.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='history', full_name='routerrpc.QueryProbabilityResponse.history', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2103,
  serialized_end=2188,
)


_BUILDROUTEREQUEST = _descriptor.Descriptor(
  name='BuildRouteRequest',
  full_name='routerrpc.BuildRouteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amt_msat', full_name='routerrpc.BuildRouteRequest.amt_msat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='final_cltv_delta', full_name='routerrpc.BuildRouteRequest.final_cltv_delta', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_chan_id', full_name='routerrpc.BuildRouteRequest.outgoing_chan_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hop_pubkeys', full_name='routerrpc.BuildRouteRequest.hop_pubkeys', index=3,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_addr', full_name='routerrpc.BuildRouteRequest.payment_addr', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2191,
  serialized_end=2327,
)


_BUILDROUTERESPONSE = _descriptor.Descriptor(
  name='BuildRouteResponse',
  full_name='routerrpc.BuildRouteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='route', full_name='routerrpc.BuildRouteResponse.route', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2329,
  serialized_end=2378,
)


_SUBSCRIBEHTLCEVENTSREQUEST = _descriptor.Descriptor(
  name='SubscribeHtlcEventsRequest',
  full_name='routerrpc.SubscribeHtlcEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2380,
  serialized_end=2408,
)


_HTLCEVENT = _descriptor.Descriptor(
  name='HtlcEvent',
  full_name='routerrpc.HtlcEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='incoming_channel_id', full_name='routerrpc.HtlcEvent.incoming_channel_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_channel_id', full_name='routerrpc.HtlcEvent.outgoing_channel_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='incoming_htlc_id', full_name='routerrpc.HtlcEvent.incoming_htlc_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_htlc_id', full_name='routerrpc.HtlcEvent.outgoing_htlc_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_ns', full_name='routerrpc.HtlcEvent.timestamp_ns', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_type', full_name='routerrpc.HtlcEvent.event_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_event', full_name='routerrpc.HtlcEvent.forward_event', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_fail_event', full_name='routerrpc.HtlcEvent.forward_fail_event', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settle_event', full_name='routerrpc.HtlcEvent.settle_event', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link_fail_event', full_name='routerrpc.HtlcEvent.link_fail_event', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HTLCEVENT_EVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='routerrpc.HtlcEvent.event',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2411,
  serialized_end=2887,
)


_HTLCINFO = _descriptor.Descriptor(
  name='HtlcInfo',
  full_name='routerrpc.HtlcInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='incoming_timelock', full_name='routerrpc.HtlcInfo.incoming_timelock', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_timelock', full_name='routerrpc.HtlcInfo.outgoing_timelock', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='incoming_amt_msat', full_name='routerrpc.HtlcInfo.incoming_amt_msat', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_amt_msat', full_name='routerrpc.HtlcInfo.outgoing_amt_msat', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2889,
  serialized_end=3007,
)


_FORWARDEVENT = _descriptor.Descriptor(
  name='ForwardEvent',
  full_name='routerrpc.ForwardEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='routerrpc.ForwardEvent.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3009,
  serialized_end=3058,
)


_FORWARDFAILEVENT = _descriptor.Descriptor(
  name='ForwardFailEvent',
  full_name='routerrpc.ForwardFailEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3060,
  serialized_end=3078,
)


_SETTLEEVENT = _descriptor.Descriptor(
  name='SettleEvent',
  full_name='routerrpc.SettleEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preimage', full_name='routerrpc.SettleEvent.preimage', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3080,
  serialized_end=3111,
)


_LINKFAILEVENT = _descriptor.Descriptor(
  name='LinkFailEvent',
  full_name='routerrpc.LinkFailEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='routerrpc.LinkFailEvent.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wire_failure', full_name='routerrpc.LinkFailEvent.wire_failure', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_detail', full_name='routerrpc.LinkFailEvent.failure_detail', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_string', full_name='routerrpc.LinkFailEvent.failure_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3114,
  serialized_end=3288,
)


_PAYMENTSTATUS = _descriptor.Descriptor(
  name='PaymentStatus',
  full_name='routerrpc.PaymentStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='routerrpc.PaymentStatus.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preimage', full_name='routerrpc.PaymentStatus.preimage', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='htlcs', full_name='routerrpc.PaymentStatus.htlcs', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3290,
  serialized_end=3404,
)


_CIRCUITKEY = _descriptor.Descriptor(
  name='CircuitKey',
  full_name='routerrpc.CircuitKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chan_id', full_name='routerrpc.CircuitKey.chan_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='htlc_id', full_name='routerrpc.CircuitKey.htlc_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3406,
  serialized_end=3452,
)


_FORWARDHTLCINTERCEPTREQUEST_CUSTOMRECORDSENTRY = _descriptor.Descriptor(
  name='CustomRecordsEntry',
  full_name='routerrpc.ForwardHtlcInterceptRequest.CustomRecordsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='routerrpc.ForwardHtlcInterceptRequest.CustomRecordsEntry.key', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='routerrpc.ForwardHtlcInterceptRequest.CustomRecordsEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3810,
  serialized_end=3862,
)

_FORWARDHTLCINTERCEPTREQUEST = _descriptor.Descriptor(
  name='ForwardHtlcInterceptRequest',
  full_name='routerrpc.ForwardHtlcInterceptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='incoming_circuit_key', full_name='routerrpc.ForwardHtlcInterceptRequest.incoming_circuit_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='incoming_amount_msat', full_name='routerrpc.ForwardHtlcInterceptRequest.incoming_amount_msat', index=1,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='incoming_expiry', full_name='routerrpc.ForwardHtlcInterceptRequest.incoming_expiry', index=2,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_hash', full_name='routerrpc.ForwardHtlcInterceptRequest.payment_hash', index=3,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_requested_chan_id', full_name='routerrpc.ForwardHtlcInterceptRequest.outgoing_requested_chan_id', index=4,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_amount_msat', full_name='routerrpc.ForwardHtlcInterceptRequest.outgoing_amount_msat', index=5,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outgoing_expiry', full_name='routerrpc.ForwardHtlcInterceptRequest.outgoing_expiry', index=6,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_records', full_name='routerrpc.ForwardHtlcInterceptRequest.custom_records', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onion_blob', full_name='routerrpc.ForwardHtlcInterceptRequest.onion_blob', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FORWARDHTLCINTERCEPTREQUEST_CUSTOMRECORDSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3455,
  serialized_end=3862,
)


_FORWARDHTLCINTERCEPTRESPONSE = _descriptor.Descriptor(
  name='ForwardHtlcInterceptResponse',
  full_name='routerrpc.ForwardHtlcInterceptResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='incoming_circuit_key', full_name='routerrpc.ForwardHtlcInterceptResponse.incoming_circuit_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='routerrpc.ForwardHtlcInterceptResponse.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preimage', full_name='routerrpc.ForwardHtlcInterceptResponse.preimage', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3865,
  serialized_end=4019,
)


_UPDATECHANSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateChanStatusRequest',
  full_name='routerrpc.UpdateChanStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chan_point', full_name='routerrpc.UpdateChanStatusRequest.chan_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='routerrpc.UpdateChanStatusRequest.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4021,
  serialized_end=4132,
)


_UPDATECHANSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateChanStatusResponse',
  full_name='routerrpc.UpdateChanStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4134,
  serialized_end=4160,
)

_SENDPAYMENTREQUEST_DESTCUSTOMRECORDSENTRY.containing_type = _SENDPAYMENTREQUEST
_SENDPAYMENTREQUEST.fields_by_name['route_hints'].message_type = lightning__pb2._ROUTEHINT
_SENDPAYMENTREQUEST.fields_by_name['dest_custom_records'].message_type = _SENDPAYMENTREQUEST_DESTCUSTOMRECORDSENTRY
_SENDPAYMENTREQUEST.fields_by_name['dest_features'].enum_type = lightning__pb2._FEATUREBIT
_SENDTOROUTEREQUEST.fields_by_name['route'].message_type = lightning__pb2._ROUTE
_SENDTOROUTERESPONSE.fields_by_name['failure'].message_type = lightning__pb2._FAILURE
_QUERYMISSIONCONTROLRESPONSE.fields_by_name['pairs'].message_type = _PAIRHISTORY
_XIMPORTMISSIONCONTROLREQUEST.fields_by_name['pairs'].message_type = _PAIRHISTORY
_PAIRHISTORY.fields_by_name['history'].message_type = _PAIRDATA
_GETMISSIONCONTROLCONFIGRESPONSE.fields_by_name['config'].message_type = _MISSIONCONTROLCONFIG
_SETMISSIONCONTROLCONFIGREQUEST.fields_by_name['config'].message_type = _MISSIONCONTROLCONFIG
_QUERYPROBABILITYRESPONSE.fields_by_name['history'].message_type = _PAIRDATA
_BUILDROUTERESPONSE.fields_by_name['route'].message_type = lightning__pb2._ROUTE
_HTLCEVENT.fields_by_name['event_type'].enum_type = _HTLCEVENT_EVENTTYPE
_HTLCEVENT.fields_by_name['forward_event'].message_type = _FORWARDEVENT
_HTLCEVENT.fields_by_name['forward_fail_event'].message_type = _FORWARDFAILEVENT
_HTLCEVENT.fields_by_name['settle_event'].message_type = _SETTLEEVENT
_HTLCEVENT.fields_by_name['link_fail_event'].message_type = _LINKFAILEVENT
_HTLCEVENT_EVENTTYPE.containing_type = _HTLCEVENT
_HTLCEVENT.oneofs_by_name['event'].fields.append(
  _HTLCEVENT.fields_by_name['forward_event'])
_HTLCEVENT.fields_by_name['forward_event'].containing_oneof = _HTLCEVENT.oneofs_by_name['event']
_HTLCEVENT.oneofs_by_name['event'].fields.append(
  _HTLCEVENT.fields_by_name['forward_fail_event'])
_HTLCEVENT.fields_by_name['forward_fail_event'].containing_oneof = _HTLCEVENT.oneofs_by_name['event']
_HTLCEVENT.oneofs_by_name['event'].fields.append(
  _HTLCEVENT.fields_by_name['settle_event'])
_HTLCEVENT.fields_by_name['settle_event'].containing_oneof = _HTLCEVENT.oneofs_by_name['event']
_HTLCEVENT.oneofs_by_name['event'].fields.append(
  _HTLCEVENT.fields_by_name['link_fail_event'])
_HTLCEVENT.fields_by_name['link_fail_event'].containing_oneof = _HTLCEVENT.oneofs_by_name['event']
_FORWARDEVENT.fields_by_name['info'].message_type = _HTLCINFO
_LINKFAILEVENT.fields_by_name['info'].message_type = _HTLCINFO
_LINKFAILEVENT.fields_by_name['wire_failure'].enum_type = lightning__pb2._FAILURE_FAILURECODE
_LINKFAILEVENT.fields_by_name['failure_detail'].enum_type = _FAILUREDETAIL
_PAYMENTSTATUS.fields_by_name['state'].enum_type = _PAYMENTSTATE
_PAYMENTSTATUS.fields_by_name['htlcs'].message_type = lightning__pb2._HTLCATTEMPT
_FORWARDHTLCINTERCEPTREQUEST_CUSTOMRECORDSENTRY.containing_type = _FORWARDHTLCINTERCEPTREQUEST
_FORWARDHTLCINTERCEPTREQUEST.fields_by_name['incoming_circuit_key'].message_type = _CIRCUITKEY
_FORWARDHTLCINTERCEPTREQUEST.fields_by_name['custom_records'].message_type = _FORWARDHTLCINTERCEPTREQUEST_CUSTOMRECORDSENTRY
_FORWARDHTLCINTERCEPTRESPONSE.fields_by_name['incoming_circuit_key'].message_type = _CIRCUITKEY
_FORWARDHTLCINTERCEPTRESPONSE.fields_by_name['action'].enum_type = _RESOLVEHOLDFORWARDACTION
_UPDATECHANSTATUSREQUEST.fields_by_name['chan_point'].message_type = lightning__pb2._CHANNELPOINT
_UPDATECHANSTATUSREQUEST.fields_by_name['action'].enum_type = _CHANSTATUSACTION
DESCRIPTOR.message_types_by_name['SendPaymentRequest'] = _SENDPAYMENTREQUEST
DESCRIPTOR.message_types_by_name['TrackPaymentRequest'] = _TRACKPAYMENTREQUEST
DESCRIPTOR.message_types_by_name['RouteFeeRequest'] = _ROUTEFEEREQUEST
DESCRIPTOR.message_types_by_name['RouteFeeResponse'] = _ROUTEFEERESPONSE
DESCRIPTOR.message_types_by_name['SendToRouteRequest'] = _SENDTOROUTEREQUEST
DESCRIPTOR.message_types_by_name['SendToRouteResponse'] = _SENDTOROUTERESPONSE
DESCRIPTOR.message_types_by_name['ResetMissionControlRequest'] = _RESETMISSIONCONTROLREQUEST
DESCRIPTOR.message_types_by_name['ResetMissionControlResponse'] = _RESETMISSIONCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['QueryMissionControlRequest'] = _QUERYMISSIONCONTROLREQUEST
DESCRIPTOR.message_types_by_name['QueryMissionControlResponse'] = _QUERYMISSIONCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['XImportMissionControlRequest'] = _XIMPORTMISSIONCONTROLREQUEST
DESCRIPTOR.message_types_by_name['XImportMissionControlResponse'] = _XIMPORTMISSIONCONTROLRESPONSE
DESCRIPTOR.message_types_by_name['PairHistory'] = _PAIRHISTORY
DESCRIPTOR.message_types_by_name['PairData'] = _PAIRDATA
DESCRIPTOR.message_types_by_name['GetMissionControlConfigRequest'] = _GETMISSIONCONTROLCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetMissionControlConfigResponse'] = _GETMISSIONCONTROLCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetMissionControlConfigRequest'] = _SETMISSIONCONTROLCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetMissionControlConfigResponse'] = _SETMISSIONCONTROLCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['MissionControlConfig'] = _MISSIONCONTROLCONFIG
DESCRIPTOR.message_types_by_name['QueryProbabilityRequest'] = _QUERYPROBABILITYREQUEST
DESCRIPTOR.message_types_by_name['QueryProbabilityResponse'] = _QUERYPROBABILITYRESPONSE
DESCRIPTOR.message_types_by_name['BuildRouteRequest'] = _BUILDROUTEREQUEST
DESCRIPTOR.message_types_by_name['BuildRouteResponse'] = _BUILDROUTERESPONSE
DESCRIPTOR.message_types_by_name['SubscribeHtlcEventsRequest'] = _SUBSCRIBEHTLCEVENTSREQUEST
DESCRIPTOR.message_types_by_name['HtlcEvent'] = _HTLCEVENT
DESCRIPTOR.message_types_by_name['HtlcInfo'] = _HTLCINFO
DESCRIPTOR.message_types_by_name['ForwardEvent'] = _FORWARDEVENT
DESCRIPTOR.message_types_by_name['ForwardFailEvent'] = _FORWARDFAILEVENT
DESCRIPTOR.message_types_by_name['SettleEvent'] = _SETTLEEVENT
DESCRIPTOR.message_types_by_name['LinkFailEvent'] = _LINKFAILEVENT
DESCRIPTOR.message_types_by_name['PaymentStatus'] = _PAYMENTSTATUS
DESCRIPTOR.message_types_by_name['CircuitKey'] = _CIRCUITKEY
DESCRIPTOR.message_types_by_name['ForwardHtlcInterceptRequest'] = _FORWARDHTLCINTERCEPTREQUEST
DESCRIPTOR.message_types_by_name['ForwardHtlcInterceptResponse'] = _FORWARDHTLCINTERCEPTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateChanStatusRequest'] = _UPDATECHANSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateChanStatusResponse'] = _UPDATECHANSTATUSRESPONSE
DESCRIPTOR.enum_types_by_name['FailureDetail'] = _FAILUREDETAIL
DESCRIPTOR.enum_types_by_name['PaymentState'] = _PAYMENTSTATE
DESCRIPTOR.enum_types_by_name['ResolveHoldForwardAction'] = _RESOLVEHOLDFORWARDACTION
DESCRIPTOR.enum_types_by_name['ChanStatusAction'] = _CHANSTATUSACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendPaymentRequest = _reflection.GeneratedProtocolMessageType('SendPaymentRequest', (_message.Message,), {

  'DestCustomRecordsEntry' : _reflection.GeneratedProtocolMessageType('DestCustomRecordsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SENDPAYMENTREQUEST_DESTCUSTOMRECORDSENTRY,
    '__module__' : 'router_pb2'
    # @@protoc_insertion_point(class_scope:routerrpc.SendPaymentRequest.DestCustomRecordsEntry)
    })
  ,
  'DESCRIPTOR' : _SENDPAYMENTREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendPaymentRequest)
  })
_sym_db.RegisterMessage(SendPaymentRequest)
_sym_db.RegisterMessage(SendPaymentRequest.DestCustomRecordsEntry)

TrackPaymentRequest = _reflection.GeneratedProtocolMessageType('TrackPaymentRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRACKPAYMENTREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.TrackPaymentRequest)
  })
_sym_db.RegisterMessage(TrackPaymentRequest)

RouteFeeRequest = _reflection.GeneratedProtocolMessageType('RouteFeeRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEFEEREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeRequest)
  })
_sym_db.RegisterMessage(RouteFeeRequest)

RouteFeeResponse = _reflection.GeneratedProtocolMessageType('RouteFeeResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEFEERESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeResponse)
  })
_sym_db.RegisterMessage(RouteFeeResponse)

SendToRouteRequest = _reflection.GeneratedProtocolMessageType('SendToRouteRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDTOROUTEREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendToRouteRequest)
  })
_sym_db.RegisterMessage(SendToRouteRequest)

SendToRouteResponse = _reflection.GeneratedProtocolMessageType('SendToRouteResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDTOROUTERESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SendToRouteResponse)
  })
_sym_db.RegisterMessage(SendToRouteResponse)

ResetMissionControlRequest = _reflection.GeneratedProtocolMessageType('ResetMissionControlRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETMISSIONCONTROLREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ResetMissionControlRequest)
  })
_sym_db.RegisterMessage(ResetMissionControlRequest)

ResetMissionControlResponse = _reflection.GeneratedProtocolMessageType('ResetMissionControlResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETMISSIONCONTROLRESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ResetMissionControlResponse)
  })
_sym_db.RegisterMessage(ResetMissionControlResponse)

QueryMissionControlRequest = _reflection.GeneratedProtocolMessageType('QueryMissionControlRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMISSIONCONTROLREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.QueryMissionControlRequest)
  })
_sym_db.RegisterMessage(QueryMissionControlRequest)

QueryMissionControlResponse = _reflection.GeneratedProtocolMessageType('QueryMissionControlResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMISSIONCONTROLRESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.QueryMissionControlResponse)
  })
_sym_db.RegisterMessage(QueryMissionControlResponse)

XImportMissionControlRequest = _reflection.GeneratedProtocolMessageType('XImportMissionControlRequest', (_message.Message,), {
  'DESCRIPTOR' : _XIMPORTMISSIONCONTROLREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.XImportMissionControlRequest)
  })
_sym_db.RegisterMessage(XImportMissionControlRequest)

XImportMissionControlResponse = _reflection.GeneratedProtocolMessageType('XImportMissionControlResponse', (_message.Message,), {
  'DESCRIPTOR' : _XIMPORTMISSIONCONTROLRESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.XImportMissionControlResponse)
  })
_sym_db.RegisterMessage(XImportMissionControlResponse)

PairHistory = _reflection.GeneratedProtocolMessageType('PairHistory', (_message.Message,), {
  'DESCRIPTOR' : _PAIRHISTORY,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PairHistory)
  })
_sym_db.RegisterMessage(PairHistory)

PairData = _reflection.GeneratedProtocolMessageType('PairData', (_message.Message,), {
  'DESCRIPTOR' : _PAIRDATA,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PairData)
  })
_sym_db.RegisterMessage(PairData)

GetMissionControlConfigRequest = _reflection.GeneratedProtocolMessageType('GetMissionControlConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMISSIONCONTROLCONFIGREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.GetMissionControlConfigRequest)
  })
_sym_db.RegisterMessage(GetMissionControlConfigRequest)

GetMissionControlConfigResponse = _reflection.GeneratedProtocolMessageType('GetMissionControlConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMISSIONCONTROLCONFIGRESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.GetMissionControlConfigResponse)
  })
_sym_db.RegisterMessage(GetMissionControlConfigResponse)

SetMissionControlConfigRequest = _reflection.GeneratedProtocolMessageType('SetMissionControlConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMISSIONCONTROLCONFIGREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SetMissionControlConfigRequest)
  })
_sym_db.RegisterMessage(SetMissionControlConfigRequest)

SetMissionControlConfigResponse = _reflection.GeneratedProtocolMessageType('SetMissionControlConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETMISSIONCONTROLCONFIGRESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SetMissionControlConfigResponse)
  })
_sym_db.RegisterMessage(SetMissionControlConfigResponse)

MissionControlConfig = _reflection.GeneratedProtocolMessageType('MissionControlConfig', (_message.Message,), {
  'DESCRIPTOR' : _MISSIONCONTROLCONFIG,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.MissionControlConfig)
  })
_sym_db.RegisterMessage(MissionControlConfig)

QueryProbabilityRequest = _reflection.GeneratedProtocolMessageType('QueryProbabilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPROBABILITYREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.QueryProbabilityRequest)
  })
_sym_db.RegisterMessage(QueryProbabilityRequest)

QueryProbabilityResponse = _reflection.GeneratedProtocolMessageType('QueryProbabilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPROBABILITYRESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.QueryProbabilityResponse)
  })
_sym_db.RegisterMessage(QueryProbabilityResponse)

BuildRouteRequest = _reflection.GeneratedProtocolMessageType('BuildRouteRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUILDROUTEREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.BuildRouteRequest)
  })
_sym_db.RegisterMessage(BuildRouteRequest)

BuildRouteResponse = _reflection.GeneratedProtocolMessageType('BuildRouteResponse', (_message.Message,), {
  'DESCRIPTOR' : _BUILDROUTERESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.BuildRouteResponse)
  })
_sym_db.RegisterMessage(BuildRouteResponse)

SubscribeHtlcEventsRequest = _reflection.GeneratedProtocolMessageType('SubscribeHtlcEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEHTLCEVENTSREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SubscribeHtlcEventsRequest)
  })
_sym_db.RegisterMessage(SubscribeHtlcEventsRequest)

HtlcEvent = _reflection.GeneratedProtocolMessageType('HtlcEvent', (_message.Message,), {
  'DESCRIPTOR' : _HTLCEVENT,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.HtlcEvent)
  })
_sym_db.RegisterMessage(HtlcEvent)

HtlcInfo = _reflection.GeneratedProtocolMessageType('HtlcInfo', (_message.Message,), {
  'DESCRIPTOR' : _HTLCINFO,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.HtlcInfo)
  })
_sym_db.RegisterMessage(HtlcInfo)

ForwardEvent = _reflection.GeneratedProtocolMessageType('ForwardEvent', (_message.Message,), {
  'DESCRIPTOR' : _FORWARDEVENT,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ForwardEvent)
  })
_sym_db.RegisterMessage(ForwardEvent)

ForwardFailEvent = _reflection.GeneratedProtocolMessageType('ForwardFailEvent', (_message.Message,), {
  'DESCRIPTOR' : _FORWARDFAILEVENT,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ForwardFailEvent)
  })
_sym_db.RegisterMessage(ForwardFailEvent)

SettleEvent = _reflection.GeneratedProtocolMessageType('SettleEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETTLEEVENT,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.SettleEvent)
  })
_sym_db.RegisterMessage(SettleEvent)

LinkFailEvent = _reflection.GeneratedProtocolMessageType('LinkFailEvent', (_message.Message,), {
  'DESCRIPTOR' : _LINKFAILEVENT,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.LinkFailEvent)
  })
_sym_db.RegisterMessage(LinkFailEvent)

PaymentStatus = _reflection.GeneratedProtocolMessageType('PaymentStatus', (_message.Message,), {
  'DESCRIPTOR' : _PAYMENTSTATUS,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PaymentStatus)
  })
_sym_db.RegisterMessage(PaymentStatus)

CircuitKey = _reflection.GeneratedProtocolMessageType('CircuitKey', (_message.Message,), {
  'DESCRIPTOR' : _CIRCUITKEY,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.CircuitKey)
  })
_sym_db.RegisterMessage(CircuitKey)

ForwardHtlcInterceptRequest = _reflection.GeneratedProtocolMessageType('ForwardHtlcInterceptRequest', (_message.Message,), {

  'CustomRecordsEntry' : _reflection.GeneratedProtocolMessageType('CustomRecordsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FORWARDHTLCINTERCEPTREQUEST_CUSTOMRECORDSENTRY,
    '__module__' : 'router_pb2'
    # @@protoc_insertion_point(class_scope:routerrpc.ForwardHtlcInterceptRequest.CustomRecordsEntry)
    })
  ,
  'DESCRIPTOR' : _FORWARDHTLCINTERCEPTREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ForwardHtlcInterceptRequest)
  })
_sym_db.RegisterMessage(ForwardHtlcInterceptRequest)
_sym_db.RegisterMessage(ForwardHtlcInterceptRequest.CustomRecordsEntry)

ForwardHtlcInterceptResponse = _reflection.GeneratedProtocolMessageType('ForwardHtlcInterceptResponse', (_message.Message,), {
  'DESCRIPTOR' : _FORWARDHTLCINTERCEPTRESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.ForwardHtlcInterceptResponse)
  })
_sym_db.RegisterMessage(ForwardHtlcInterceptResponse)

UpdateChanStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateChanStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECHANSTATUSREQUEST,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.UpdateChanStatusRequest)
  })
_sym_db.RegisterMessage(UpdateChanStatusRequest)

UpdateChanStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateChanStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECHANSTATUSRESPONSE,
  '__module__' : 'router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.UpdateChanStatusResponse)
  })
_sym_db.RegisterMessage(UpdateChanStatusResponse)


DESCRIPTOR._options = None
_SENDPAYMENTREQUEST_DESTCUSTOMRECORDSENTRY._options = None
_SENDPAYMENTREQUEST.fields_by_name['outgoing_chan_id']._options = None
_BUILDROUTEREQUEST.fields_by_name['outgoing_chan_id']._options = None
_FORWARDHTLCINTERCEPTREQUEST_CUSTOMRECORDSENTRY._options = None

_ROUTER = _descriptor.ServiceDescriptor(
  name='Router',
  full_name='routerrpc.Router',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=4973,
  serialized_end=6494,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendPaymentV2',
    full_name='routerrpc.Router.SendPaymentV2',
    index=0,
    containing_service=None,
    input_type=_SENDPAYMENTREQUEST,
    output_type=lightning__pb2._PAYMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TrackPaymentV2',
    full_name='routerrpc.Router.TrackPaymentV2',
    index=1,
    containing_service=None,
    input_type=_TRACKPAYMENTREQUEST,
    output_type=lightning__pb2._PAYMENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateRouteFee',
    full_name='routerrpc.Router.EstimateRouteFee',
    index=2,
    containing_service=None,
    input_type=_ROUTEFEEREQUEST,
    output_type=_ROUTEFEERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendToRoute',
    full_name='routerrpc.Router.SendToRoute',
    index=3,
    containing_service=None,
    input_type=_SENDTOROUTEREQUEST,
    output_type=_SENDTOROUTERESPONSE,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendToRouteV2',
    full_name='routerrpc.Router.SendToRouteV2',
    index=4,
    containing_service=None,
    input_type=_SENDTOROUTEREQUEST,
    output_type=lightning__pb2._HTLCATTEMPT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetMissionControl',
    full_name='routerrpc.Router.ResetMissionControl',
    index=5,
    containing_service=None,
    input_type=_RESETMISSIONCONTROLREQUEST,
    output_type=_RESETMISSIONCONTROLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryMissionControl',
    full_name='routerrpc.Router.QueryMissionControl',
    index=6,
    containing_service=None,
    input_type=_QUERYMISSIONCONTROLREQUEST,
    output_type=_QUERYMISSIONCONTROLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='XImportMissionControl',
    full_name='routerrpc.Router.XImportMissionControl',
    index=7,
    containing_service=None,
    input_type=_XIMPORTMISSIONCONTROLREQUEST,
    output_type=_XIMPORTMISSIONCONTROLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMissionControlConfig',
    full_name='routerrpc.Router.GetMissionControlConfig',
    index=8,
    containing_service=None,
    input_type=_GETMISSIONCONTROLCONFIGREQUEST,
    output_type=_GETMISSIONCONTROLCONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetMissionControlConfig',
    full_name='routerrpc.Router.SetMissionControlConfig',
    index=9,
    containing_service=None,
    input_type=_SETMISSIONCONTROLCONFIGREQUEST,
    output_type=_SETMISSIONCONTROLCONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryProbability',
    full_name='routerrpc.Router.QueryProbability',
    index=10,
    containing_service=None,
    input_type=_QUERYPROBABILITYREQUEST,
    output_type=_QUERYPROBABILITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BuildRoute',
    full_name='routerrpc.Router.BuildRoute',
    index=11,
    containing_service=None,
    input_type=_BUILDROUTEREQUEST,
    output_type=_BUILDROUTERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeHtlcEvents',
    full_name='routerrpc.Router.SubscribeHtlcEvents',
    index=12,
    containing_service=None,
    input_type=_SUBSCRIBEHTLCEVENTSREQUEST,
    output_type=_HTLCEVENT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendPayment',
    full_name='routerrpc.Router.SendPayment',
    index=13,
    containing_service=None,
    input_type=_SENDPAYMENTREQUEST,
    output_type=_PAYMENTSTATUS,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TrackPayment',
    full_name='routerrpc.Router.TrackPayment',
    index=14,
    containing_service=None,
    input_type=_TRACKPAYMENTREQUEST,
    output_type=_PAYMENTSTATUS,
    serialized_options=b'\210\002\001',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HtlcInterceptor',
    full_name='routerrpc.Router.HtlcInterceptor',
    index=15,
    containing_service=None,
    input_type=_FORWARDHTLCINTERCEPTRESPONSE,
    output_type=_FORWARDHTLCINTERCEPTREQUEST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateChanStatus',
    full_name='routerrpc.Router.UpdateChanStatus',
    index=16,
    containing_service=None,
    input_type=_UPDATECHANSTATUSREQUEST,
    output_type=_UPDATECHANSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROUTER)

DESCRIPTOR.services_by_name['Router'] = _ROUTER

# @@protoc_insertion_point(module_scope)



import re, setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

with open("./lndmanage/__init__.py", "r") as f:
    MATCH_EXPR = "__version__[^'\"]+(['\"])([^'\"]+)"
    VERSION = re.search(MATCH_EXPR, f.read()).group(2)

# package:
# (venv) pip install pep517 setuptools wheel sdist twine
# (venv) python3 -m pep517.build --source --binary .
# upload:
# (venv) twine upload --repository testpypi dist/*

setuptools.setup(
    name="lndmanage",
    version=VERSION,
    author="bitromortac",
    author_email="bitromortac@protonmail.com",
    description="Channel management tool for lightning network daemon (LND) "
    "operators.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bitromortac/lndmanage",
    packages=setuptools.find_packages(),
    python_requires='>3.8.0',
    install_requires=[
        "googleapis-common-protos>=1.52.0",
        "grpcio>=1.31.0",
        "grpcio-tools>=1.31.0",
        "networkx>=2.4",
        "numpy>=1.19.1",
        "protobuf>=3.12.4",
        "Pygments>=2.7.4",
    ],
    extras_require={
        "test": [
            "lnregtest>=0.2.1",
        ]
    },
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points={
        "console_scripts": [
            "lndmanage = lndmanage.lndmanage:main",
        ]
    },
)



from enum import Enum
from dataclasses import dataclass, field


class AddressType(Enum):
    WITNESS_PUBKEY_HASH = 0
    NESTED_PUBKEY_HASH = 1


@dataclass(order=True)
class UTXO:
    sort_index: int = field(init=False, repr=False)
    txid: str
    output_index: int
    amount_sat: int = None
    transaction_type: AddressType = None

    def __post_init__(self):
        self.sort_index = self.amount_sat

    def __hash__(self):
        return hash(self.txid) + hash(self.output_index)

    def __eq__(self, other: "UTXO"):
        if self.txid == other.txid and self.output_index == other.output_index:
            return True
        else:
            return False

    def __str__(self):
        return f"{self.txid}:{self.output_index} {self.amount_sat} sat"


@dataclass(order=True)
class NodeProperties:
    age: int
    local_fee_rates: list
    local_base_fees: list
    local_balances: list
    number_active_channels: int
    number_channels: int
    number_private_channels: int
    public_capacities: list
    private_capacites: list
    remote_fee_rates: list
    remote_base_fees: list
    remote_balances: list
    sent_received_per_week: int



from unittest import TestCase

from lnregtest.lib.graph_testing import graph_test
from test.graph_definitions.star_ring_4_illiquid import nodes


class TestStarRing4Illiquid(TestCase):
    def test_graph(self):
        graph_test(nodes)



import collections
import time

import logging
logger = logging.getLogger(__name__)
logger.addHandler(logging.NullHandler())


def convert_dictionary_number_strings_to_ints(data):
    """
    Converts the values of str type to int type where possible.

    :param data: dict
    :return: converted dict
    """
    if isinstance(data, str):
        try:
            data = int(data)
        except ValueError:
            data = str(data)
        return data
    elif isinstance(data, collections.Mapping):
        return dict(map(convert_dictionary_number_strings_to_ints, data.items()))
    elif isinstance(data, collections.Iterable):
        return type(data)(map(convert_dictionary_number_strings_to_ints, data))
    else:
        return data


def profiled(func, *args, **kwargs):
    """Function wrapper for measuring execution time."""
    def wrapper(*args, **kwargs):
        name = func.__qualname__
        start = time.time()
        output = func(*args, **kwargs)
        delta = time.time() - start
        logger.debug(f"{name} {delta:,.4f} s")
        return output
    return wrapper